@@ -6,27 +6,29 @@ from one_interfaces import user_pb2 as User
 
 
 class CoreApi:
-    def __init__(self, env, auth:AuthenticationApi):
+    def __init__(self, env, auth: AuthenticationApi, session: requests.Session =None):
         self.AppUrl = "/enterprise/core/v1/"
         self.Environment = env
         self.Authentication = auth
-    
-    def GetUser(self, userId, expand = None):
+        if not session:
+            self.Session = requests.Session()
+            self.Session.headers = {"Content-Type": "application/x-protobuf", "Accept": "application/x-protobuf"}            
+        else:
+            self.Session = session
+
+    def GetUser(self, userId, expand=None):
         user = User.User()
-        if (expand!=None):
+        if (expand != None):
             url = self.Environment+self.AppUrl+"User/"+userId+"expand="+expand
         else:
             url = self.Environment+self.AppUrl+"User/"+userId
-        headers = {'Authorization': self.Authentication.Token.access_token, "Accept":"application/x-protobuf"}
-        response = DeserializeResponse(requests.get(url, headers=headers))       
-        if response.errors:            
-            return response  
-        return response.content.users.items[0]      
-             
-    
+        
+        response = DeserializeResponse(self.Session.get(url))
+        if response.errors:
+            return response
+        return response.content.users.items[0]
+
 
 class UserHelper:
     def GetUserFromUserInfo(userInfo):
         jResponse = json.loads(userInfo.content)
-        
-        
\ No newline at end of file
